﻿using Microsoft.AspNetCore.Mvc;
using AutoMapperProjectionsWithEntityFrameworkCore.Models;
using AutoMapperProjectionsWithEntityFrameworkCore.Data;
using System.Linq;
using AutoMapper.QueryableExtensions;
using System.Collections.Generic;
using AutoMapper;

namespace AutoMapperProjectionsWithEntityFrameworkCore.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class ProductsController : ControllerBase
    {
        private readonly SalesContext _salesContext;  

        public ProductsController (SalesContext salesContext)
        {
            _salesContext = salesContext;
        }

        [HttpGet("{count}")]
        public ActionResult Get(int count)
        {
            return Ok(_salesContext.Products.OrderBy(p => p.ProductId).Take(count));
        }

        [HttpGet("mapped/{count}")]
        public ActionResult GetMapped(int count)
        {
            List<Product> products = _salesContext.Products.OrderBy(p => p.ProductId).Take(count).ToList();
            List<ProductModel> productModels = Mapper.Map<List<ProductModel>>(products);
            return Ok(productModels);
        }

        [HttpGet("projected/{count}")]
        public ActionResult GetProjected(int count)
        {
            return Ok(_salesContext.Products.OrderBy(p => p.ProductId).Take(count).ProjectTo<ProductModel>());
        }

    }
}
